"""
sketch_matrix_decompress

Autogenerated DPF operator classes.
"""

from warnings import warn
from ansys.dpf.core.dpf_operator import Operator
from ansys.dpf.core.inputs import Input, _Inputs
from ansys.dpf.core.outputs import Output, _Outputs
from ansys.dpf.core.operators.specification import PinSpecification, Specification


class sketch_matrix_decompress(Operator):
    """Decompress fields container using an orthonormal randomized (Gaussian
    distribution) sketch matrix.

    Parameters
    ----------
    dataIn : FieldsContainer
        Fields container to be decompressed. it is
        assumed that all fields have the same
        structure (scoping, num_entities).
    sketch_matrix : Field
        Field containing the sketch matrix.
    shell_field : Field
        Empty field containing the shell of the field
        of decompressed data.

    Returns
    -------
    dataOut : FieldsContainer
        The output matrix is a 'fields_container';
        each field correspond to the
        multiplication of the sketch matrix
        by the original fields.

    Examples
    --------
    >>> from ansys.dpf import core as dpf

    >>> # Instantiate operator
    >>> op = dpf.operators.compression.sketch_matrix_decompress()

    >>> # Make input connections
    >>> my_dataIn = dpf.FieldsContainer()
    >>> op.inputs.dataIn.connect(my_dataIn)
    >>> my_sketch_matrix = dpf.Field()
    >>> op.inputs.sketch_matrix.connect(my_sketch_matrix)
    >>> my_shell_field = dpf.Field()
    >>> op.inputs.shell_field.connect(my_shell_field)

    >>> # Instantiate operator and connect inputs in one line
    >>> op = dpf.operators.compression.sketch_matrix_decompress(
    ...     dataIn=my_dataIn,
    ...     sketch_matrix=my_sketch_matrix,
    ...     shell_field=my_shell_field,
    ... )

    >>> # Get output data
    >>> result_dataOut = op.outputs.dataOut()
    """

    def __init__(
        self,
        dataIn=None,
        sketch_matrix=None,
        shell_field=None,
        config=None,
        server=None,
    ):
        super().__init__(name="sketch_matrix_decompress", config=config, server=server)
        self._inputs = InputsSketchMatrixDecompress(self)
        self._outputs = OutputsSketchMatrixDecompress(self)
        if dataIn is not None:
            self.inputs.dataIn.connect(dataIn)
        if sketch_matrix is not None:
            self.inputs.sketch_matrix.connect(sketch_matrix)
        if shell_field is not None:
            self.inputs.shell_field.connect(shell_field)

    @staticmethod
    def _spec():
        description = """Decompress fields container using an orthonormal randomized (Gaussian
            distribution) sketch matrix."""
        spec = Specification(
            description=description,
            map_input_pin_spec={
                0: PinSpecification(
                    name="dataIn",
                    type_names=["fields_container"],
                    optional=False,
                    document="""Fields container to be decompressed. it is
        assumed that all fields have the same
        structure (scoping, num_entities).""",
                ),
                1: PinSpecification(
                    name="sketch_matrix",
                    type_names=["field"],
                    optional=False,
                    document="""Field containing the sketch matrix.""",
                ),
                2: PinSpecification(
                    name="shell_field",
                    type_names=["field"],
                    optional=False,
                    document="""Empty field containing the shell of the field
        of decompressed data.""",
                ),
            },
            map_output_pin_spec={
                0: PinSpecification(
                    name="dataOut",
                    type_names=["fields_container"],
                    optional=False,
                    document="""The output matrix is a 'fields_container';
        each field correspond to the
        multiplication of the sketch matrix
        by the original fields.""",
                ),
            },
        )
        return spec

    @staticmethod
    def default_config(server=None):
        """Returns the default config of the operator.

        This config can then be changed to the user needs and be used to
        instantiate the operator. The Configuration allows to customize
        how the operation will be processed by the operator.

        Parameters
        ----------
        server : server.DPFServer, optional
            Server with channel connected to the remote or local instance. When
            ``None``, attempts to use the global server.
        """
        return Operator.default_config(name="sketch_matrix_decompress", server=server)

    @property
    def inputs(self):
        """Enables to connect inputs to the operator

        Returns
        --------
        inputs : InputsSketchMatrixDecompress
        """
        return super().inputs

    @property
    def outputs(self):
        """Enables to get outputs of the operator by evaluating it

        Returns
        --------
        outputs : OutputsSketchMatrixDecompress
        """
        return super().outputs


class InputsSketchMatrixDecompress(_Inputs):
    """Intermediate class used to connect user inputs to
    sketch_matrix_decompress operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.compression.sketch_matrix_decompress()
    >>> my_dataIn = dpf.FieldsContainer()
    >>> op.inputs.dataIn.connect(my_dataIn)
    >>> my_sketch_matrix = dpf.Field()
    >>> op.inputs.sketch_matrix.connect(my_sketch_matrix)
    >>> my_shell_field = dpf.Field()
    >>> op.inputs.shell_field.connect(my_shell_field)
    """

    def __init__(self, op: Operator):
        super().__init__(sketch_matrix_decompress._spec().inputs, op)
        self._dataIn = Input(sketch_matrix_decompress._spec().input_pin(0), 0, op, -1)
        self._inputs.append(self._dataIn)
        self._sketch_matrix = Input(
            sketch_matrix_decompress._spec().input_pin(1), 1, op, -1
        )
        self._inputs.append(self._sketch_matrix)
        self._shell_field = Input(
            sketch_matrix_decompress._spec().input_pin(2), 2, op, -1
        )
        self._inputs.append(self._shell_field)

    @property
    def dataIn(self):
        """Allows to connect dataIn input to the operator.

        Fields container to be decompressed. it is
        assumed that all fields have the same
        structure (scoping, num_entities).

        Parameters
        ----------
        my_dataIn : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.compression.sketch_matrix_decompress()
        >>> op.inputs.dataIn.connect(my_dataIn)
        >>> # or
        >>> op.inputs.dataIn(my_dataIn)
        """
        return self._dataIn

    @property
    def sketch_matrix(self):
        """Allows to connect sketch_matrix input to the operator.

        Field containing the sketch matrix.

        Parameters
        ----------
        my_sketch_matrix : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.compression.sketch_matrix_decompress()
        >>> op.inputs.sketch_matrix.connect(my_sketch_matrix)
        >>> # or
        >>> op.inputs.sketch_matrix(my_sketch_matrix)
        """
        return self._sketch_matrix

    @property
    def shell_field(self):
        """Allows to connect shell_field input to the operator.

        Empty field containing the shell of the field
        of decompressed data.

        Parameters
        ----------
        my_shell_field : Field

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.compression.sketch_matrix_decompress()
        >>> op.inputs.shell_field.connect(my_shell_field)
        >>> # or
        >>> op.inputs.shell_field(my_shell_field)
        """
        return self._shell_field


class OutputsSketchMatrixDecompress(_Outputs):
    """Intermediate class used to get outputs from
    sketch_matrix_decompress operator.

    Examples
    --------
    >>> from ansys.dpf import core as dpf
    >>> op = dpf.operators.compression.sketch_matrix_decompress()
    >>> # Connect inputs : op.inputs. ...
    >>> result_dataOut = op.outputs.dataOut()
    """

    def __init__(self, op: Operator):
        super().__init__(sketch_matrix_decompress._spec().outputs, op)
        self._dataOut = Output(sketch_matrix_decompress._spec().output_pin(0), 0, op)
        self._outputs.append(self._dataOut)

    @property
    def dataOut(self):
        """Allows to get dataOut output of the operator

        Returns
        ----------
        my_dataOut : FieldsContainer

        Examples
        --------
        >>> from ansys.dpf import core as dpf
        >>> op = dpf.operators.compression.sketch_matrix_decompress()
        >>> # Connect inputs : op.inputs. ...
        >>> result_dataOut = op.outputs.dataOut()
        """  # noqa: E501
        return self._dataOut
